==> rhapsodie_0.5.0.tar.gz: rhapsodie-0.5.0/src/commondialog.h <==
/*************************************************************************}
{ commondialog.h -dialog template                                         }
{                                                                         }
{ This file is a part of the project                                      }
{   Rhapsodie - Music player for N900                                     }
{                                                                         }
{ (c) Alexey Parfenov, 2012                                               }
{                                                                         }
{ e-mail: zxed@alkatrazstudio.net                                         }
{                                                                         }
{ This program is free software; you can redistribute it and/or           }
{ modify it under the terms of the GNU General Public License             }
{ as published by the Free Software Foundation; either version 3 of       }
{ the License, or (at your option) any later version.                     }
{                                                                         }
{ This program is distributed in the hope that it will be useful,         }
{ but WITHOUT ANY WARRANTY; without even the implied warranty of          }
{ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU        }
{ General Public License for more details.                                }
{                                                                         }
{ You may read GNU General Public License at:                             }
{   http://www.gnu.org/copyleft/gpl.html                                  }
{                                                                         }
{ last modified: 21 Mar 2012                                              }
{*************************************************************************/

#ifndef COMMONDIALOG_H
#define COMMONDIALOG_H

#include "includes.h"

class CommonDialog : public QDialog, public QWidgetHelper
{
    Q_OBJECT
public:
    explicit CommonDialog(QWidget *parent):QDialog(parent){}
    
protected:
    virtual void initGui(){}
    virtual void deinitGui(){}
    virtual int showDialog();

    virtual void reposition(const QSize& sz){Q_UNUSED(sz);}
    virtual void resizeEvent(QResizeEvent *event){reposition(event->size());}
};

#endif // COMMONDIALOG_H

==> rhapsodie_0.5.1.tar.gz: rhapsodie-0.5.1/src/commondialog.h <==
/*************************************************************************}
{ commondialog.h -dialog template                                         }
{                                                                         }
{ This file is a part of the project                                      }
{   Rhapsodie - Music player for N900                                     }
{                                                                         }
{ (c) Alexey Parfenov, 2012                                               }
{                                                                         }
{ e-mail: zxed@alkatrazstudio.net                                         }
{                                                                         }
{ This program is free software; you can redistribute it and/or           }
{ modify it under the terms of the GNU General Public License             }
{ as published by the Free Software Foundation; either version 3 of       }
{ the License, or (at your option) any later version.                     }
{                                                                         }
{ This program is distributed in the hope that it will be useful,         }
{ but WITHOUT ANY WARRANTY; without even the implied warranty of          }
{ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU        }
{ General Public License for more details.                                }
{                                                                         }
{ You may read GNU General Public License at:                             }
{   http://www.gnu.org/copyleft/gpl.html                                  }
{                                                                         }
{ last modified: 21 Mar 2012                                              }
{*************************************************************************/

#ifndef COMMONDIALOG_H
#define COMMONDIALOG_H

#include "includes.h"
#include "../inc/qwidgethelper.h"

class CommonDialog : public QDialog, public QWidgetHelper
{
    Q_OBJECT
public:
    explicit CommonDialog(QWidget *parent):QDialog(parent){}
    
protected:
    virtual void initGui(){}
    virtual void deinitGui(){}
    virtual int showDialog(ScreenOrientation forceScreenOrientation = ScreenOrientationAuto);

    virtual void reposition(const QSize& sz){Q_UNUSED(sz);}
    virtual void resizeEvent(QResizeEvent *event){reposition(event->size());}
};

#endif // COMMONDIALOG_H
